@@ -4,6 +4,7 @@ import shutil
 from copy import deepcopy
 from pathlib import Path
 import yaml
+from typing import Union
 
 from steam_sdk.data.DataSettings import DataSettingsSTEAM
 from steam_sdk.builders.BuilderModel import BuilderModel
@@ -56,14 +57,12 @@ class AnalysisSTEAM:
         # Read analysis settings
         self.read_settings()
 
-
     def setAttribute(self, dataclassSTEAM, attribute: str, value):
         try:
             setattr(dataclassSTEAM, attribute, value)
         except:
             setattr(getattr(self, dataclassSTEAM), attribute, value)
 
-
     def getAttribute(self, dataclassSTEAM, attribute):
         try:
             return getattr(dataclassSTEAM, attribute)
@@ -78,7 +77,6 @@ class AnalysisSTEAM:
              - Check if model library folder is present. If not, raise an exception.
              - Check if output folder is present. If not, make it.
              - Check if temporary folder is present. If so, delete it.
-
         """
 
         # Unpack inputs
@@ -124,7 +122,6 @@ class AnalysisSTEAM:
             shutil.rmtree(temp_path)
             print('Folder {} already existed. It was removed.'.format(temp_path))
 
-
     def read_settings(self):
         """
             ** Read analysis settings **
@@ -171,7 +168,6 @@ class AnalysisSTEAM:
             yaml.dump(dictonary_settings, yaml_file, default_flow_style=False, sort_keys=False)
         if verbose: print('File {} was saved locally.'.format(path_temp_file_settings))
 
-
     def run_analysis(self, verbose: bool = None):
         """
             ** Run the analysis **
@@ -216,12 +212,15 @@ class AnalysisSTEAM:
             else:
                 raise Exception('Unknown type of analysis step: {}'.format(step.type))
 
-
     def step_make_model(self, step, verbose: bool = False):
         if verbose:
             print('Making model object named {}'.format(str(step.model_name)))
 
         file_model_data = os.path.join(self.library_path, step.case_model + 's', step.file_model_data, 'input', 'modelData_' + step.file_model_data + '.yaml')
+        if 'FiQuS' in step.software:
+            local_model_folder = os.path.join(Path(self.settings.local_FiQuS_folder), step.simulation_name, str(step.simulation_number))
+        else:
+            local_model_folder = None
         case_model      = step.case_model
         software        = step.software  # remember this is a list, not a string
         verbose_of_step = step.verbose
@@ -234,14 +233,14 @@ class AnalysisSTEAM:
 
         # Build the model
         BM = BuilderModel(file_model_data=file_model_data, case_model=case_model, software=software,
-                          verbose=verbose_of_step, flag_build=flag_build,
-                          flag_dump_all=flag_dump_all, flag_plot_all=flag_plot_all, flag_json=flag_json,
-                          output_path=output_folder, relative_path_settings=relative_path_settings)
+                          verbose=verbose_of_step, flag_build=flag_build, flag_dump_all=flag_dump_all,
+                          flag_plot_all=flag_plot_all, flag_json=flag_json, output_path=output_folder,
+                          relative_path_settings=relative_path_settings, local_model_path=local_model_folder)
 
         # Build simulation file
         if step.simulation_number:
             if 'FiQuS' in step.software:
-                self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=step.simulation_number)
+                self.setup_sim_FiQuS(simulation_name=step.simulation_name, simulation_type=step.type, sim_number=step.simulation_number)
             if 'LEDET' in step.software:
                 flag_yaml = True  # Hard-coded for the moment
                 self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=step.simulation_number, flag_yaml=flag_yaml, flag_json=flag_json)
@@ -253,7 +252,6 @@ class AnalysisSTEAM:
         # Add the reference to the model in the dictionary
         self.list_models[step.model_name] = BM
 
-
     def step_modify_model(self, step, verbose: bool = False):
         if verbose:
             print('Modifying model object named {}'.format(str(step.model_name)))
@@ -312,8 +310,8 @@ class AnalysisSTEAM:
             if len_simulation_numbers > 0:
                 simulation_number = step.simulation_numbers[v]
                 if 'FiQuS' in step.software:
-                    BM.buildFiQuS()
-                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=simulation_number)
+                    BM.buildFiQuS(local_folder=os.path.join(Path(self.settings.local_FiQuS_folder), step.simulation_name, str(simulation_number)))
+                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, simulation_type=step.type, sim_number=simulation_number)
                 if 'LEDET' in step.software:
                     flag_json = BM.flag_json
                     flag_yaml = True  # Hard-coded for the moment
@@ -327,7 +325,7 @@ class AnalysisSTEAM:
                     self.setup_sim_PSPICE(simulation_name=step.simulation_name, sim_number=simulation_number)
 
     def get_attribute_model(self, case_model: str, builder_model: BuilderModel, name_variable: str, idx_conductor: int = None):
-        '''
+        """
         Helper function used to get an attribute from a key of the model data.
         Depending on the model type (circuit, magnet, conductor), the data structure to access is different.
         Also, there is a special case when the variable to read is a sub-key of the Conductors key. In such a case, an additional parameter idx_conductor must be defined (see below).
@@ -336,7 +334,7 @@ class AnalysisSTEAM:
         :param name_variable: Name of the variable to read
         :param idx_conductor: When defined, a sub-key form the Conductors key is read. The index of the conductor to read is defined by idx_conductor
         :return: Value of the variable to get
-        '''
+        """
 
         if case_model == 'magnet':
             if idx_conductor is None:  # Standard case when the variable to change is not the Conductors key
@@ -354,8 +352,8 @@ class AnalysisSTEAM:
             raise Exception(f'Model type not supported: case_model={case_model}')
         return value
 
-    def set_attribute_model(self, case_model: str, builder_model: BuilderModel, name_variable: str, value_variable: float, idx_conductor: int = None):
-        '''
+    def set_attribute_model(self, case_model: str, builder_model: BuilderModel, name_variable: str, value_variable: Union[int, float, str], idx_conductor: int = None):
+        """
         Helper function used to set a key of the model data to a certaub value.
         Depending on the model type (circuit, magnet, conductor), the data structure to access is different.
         Also, there is a special case when the variable to change is a sub-key of the Conductors key. In such a case, an additional parameter idx_conductor must be defined (see below).
@@ -365,7 +363,7 @@ class AnalysisSTEAM:
         :param value_variable: New value of the variable of the variable
         :param idx_conductor: When defined, a sub-key form the Conductors key is read. The index of the conductor to read is defined by idx_conductor
         :return: Value of the variable to get
-        '''
+        """
 
         if case_model == 'magnet':
             if idx_conductor is None:  # Standard case when the variable to change is not the Conductors key
@@ -382,7 +380,6 @@ class AnalysisSTEAM:
         else:
             raise Exception(f'Model type not supported: case_model={case_model}')
 
-
     def step_modify_model_multiple_variables(self, step, verbose: bool = False):
         if verbose:
             print('Modifying model object named {}'.format(str(step.model_name)))
@@ -414,7 +411,6 @@ class AnalysisSTEAM:
         if verbose:
             print('All variables of step {} were changed.'.format(step))
 
-
     def step_run_simulation(self, step, verbose: bool = False):
         software = step.software
         simulation_name = step.simulation_name
@@ -425,17 +421,15 @@ class AnalysisSTEAM:
             # Run simulation
             self.run_sim(software, simulation_name, sim_number, simFileType, verbose)
 
-
     def step_postprocess(self, step, verbose: bool = False):
         if verbose: print('postprocessing')
         pass
 
-
     def step_setup_folder(self, step, verbose: bool = False):
-        '''
+        """
         Set up simulation working folder.
         The function applies a different logic for each simulation software.
-        '''
+        """
         list_software = step.software
         simulation_name = step.simulation_name
 
@@ -497,9 +491,9 @@ class AnalysisSTEAM:
                 raise Exception(f'Software {software} not supported for automated folder setup.')
 
     def add_auxiliary_file(self, step, verbose: bool = False):
-        '''
+        """
         Copy the desired auxiliary file to the output folder
-        '''
+        """
         # Unpack
         full_path_aux_file = Path(step.full_path_aux_file).resolve()
         new_file_name      = step.new_file_name
@@ -519,7 +513,7 @@ class AnalysisSTEAM:
         if len_simulation_numbers > 0:
             for simulation_number in step.simulation_numbers:
                 if 'FiQuS' in step.software:
-                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=simulation_number)
+                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, simulation_type=step.type, sim_number=simulation_number)
                 if 'LEDET' in step.software:
                     flag_yaml = True  # Hard-coded for the moment
                     flag_json = False  # Hard-coded for the moment
@@ -529,8 +523,7 @@ class AnalysisSTEAM:
                 if 'PSPICE' in step.software:
                     self.setup_sim_PSPICE(simulation_name=step.simulation_name, sim_number=simulation_number)
 
-
-    def setup_sim_FiQuS(self, simulation_name, sim_number):
+    def setup_sim_FiQuS(self, simulation_name, simulation_type, sim_number):
         """
         Set up a FiQuS simulation by copying the last file generated by BuilderModel to the output folder and to the
         local FiQuS working folder.
@@ -551,26 +544,28 @@ class AnalysisSTEAM:
         # Copy simulation file
         file_name_temp = os.path.join(output_folder, simulation_name)
         yaml_temp = os.path.join(file_name_temp + '.yaml')
-        geo_temp = os.path.join(file_name_temp + '.geom')
-        set_temp = os.path.join(file_name_temp + '.set')
         file_name_local = os.path.join(local_model_folder, simulation_name)
         yaml_local = os.path.join(file_name_local + '.yaml')
-        geo_local = os.path.join(file_name_local + '.geom')
-        set_local = os.path.join(file_name_local + '.set')
-        print('Simulation files {} generated.'.format(file_name_temp))
-
         shutil.copyfile(yaml_temp, yaml_local)
-        shutil.copyfile(geo_temp, geo_local)
-        shutil.copyfile(set_temp, set_local)
+
+        if simulation_type == 'MakeModel':
+            geo_temp = os.path.join(file_name_temp + '.geom')
+            set_temp = os.path.join(file_name_temp + '.set')
+            geo_local = os.path.join(file_name_local + '.geom')
+            set_local = os.path.join(file_name_local + '.set')
+            shutil.copyfile(geo_temp, geo_local)
+            shutil.copyfile(set_temp, set_local)
+
+        print('Simulation files {} generated.'.format(file_name_temp))
         print('Simulation files {} copied.'.format(file_name_local))
 
     def setup_sim_LEDET(self, simulation_name, sim_number, flag_yaml=True, flag_json=False):
-        '''
+        """
         Set up a LEDET simulation by copying the last file generated by BuilderModel to the output folder and to the
         local LEDET working folder. The original file is then deleted.
         If flag_yaml=True, the model is set up to be run using a yaml input file.
         If flag_json=True, the model is set up to be run using a json input file.
-        '''
+        """
 
         # Unpack
         output_folder      = self.output_path
@@ -602,12 +597,12 @@ class AnalysisSTEAM:
 
 
     def setup_sim_PSPICE(self, simulation_name, sim_number):
-        '''
+        """
         Set up a PSPICE simulation by copying the last file generated by BuilderModel to the output folder and to the
         local PSPICE working folder.
         The simulation netlist and auxiliary files are copied in a new numbered subfoldered.
         The original file is then deleted.
-        '''
+        """
 
         # Unpack
         output_folder = self.output_path
@@ -649,11 +644,11 @@ class AnalysisSTEAM:
 
 
     def setup_sim_PyBBQ(self, simulation_name, sim_number):
-        '''
+        """
         Set up a PyBBQ simulation by copying the last file generated by BuilderModel to the output folder and to the
         local PyBBQ working folder.
         The original file is then deleted.
-        '''
+        """
 
         # Unpack
         output_folder = self.output_path
@@ -679,10 +674,10 @@ class AnalysisSTEAM:
 
 
     def run_sim(self, software: str, simulation_name: str, sim_number: int, simFileType: str = None, verbose: bool = False):
-        '''
+        """
         Run selected simulation.
         The function applies a different logic for each simulation software.
-        '''
+        """
         if software == 'FiQuS':
             local_model_folder_input = os.path.join(self.settings.local_FiQuS_folder, simulation_name, str(sim_number))
             relative_folder_output = os.path.join(simulation_name, str(sim_number))
