@@ -14,6 +14,7 @@ class BuilderFiQuS:
     def __init__(self,
                  input_model_data: dM.DataModelMagnet = None,
                  input_roxie_data: dR.RoxieData = None,
+                 local_model_path: str = None,
                  flag_build: bool = True,
                  flag_plot_all: bool = False,
                  verbose: bool = True):
@@ -24,30 +25,50 @@ class BuilderFiQuS:
         # Unpack arguments
         self.verbose: bool = verbose
         self.flag_plot_all: bool = flag_plot_all
+        self.local_folder: str = local_model_path
         self.model_data: dM.DataModelMagnet = input_model_data
         self.roxie_data: dR.RoxieData = input_roxie_data
 
-        # TODO build different objects according to self.model_data.GeneralParameters.magnet_type
-
-        # Data structure
-        self.data_FiQuS_geo = dF.FiQuSGeometry()
-        self.data_FiQuS_set = dF.FiQuSSettings()
-        self.data_FiQuS = dF.FiQuSData()
-
         if not self.model_data and flag_build:
             raise Exception('Cannot build model instantly without providing DataModelMagnet')
 
-        if flag_build:
-            # Build data structures
-            self.buildData()
+        # Data structure
+        if self.model_data:  # to avoid errors during library import
+            self.data_FiQuS = dF.DataFiQuS()
+            self.data_FiQuS.general.magnet_name = self.model_data.GeneralParameters.magnet_name
+            self.data_FiQuS.general.magnet_type = self.model_data.GeneralParameters.magnet_type
 
-    def buildData(self):
+            if self.model_data.GeneralParameters.magnet_type == 'multipole':
+                self.data_FiQuS_geo = dF.FiQuSGeometry()
+                self.data_FiQuS_set = dF.FiQuSSettings()
+                if flag_build:
+                    self.buildDataMultipole()
+
+            elif self.model_data.GeneralParameters.magnet_type == 'CCT':
+                if flag_build:
+                    self.buildDataCCT()
+
+            else:
+                raise Exception('Incompatible magnet type.')
+
+    def buildDataCCT(self):
         """
             Load selected conductor data from DataModelMagnet keys, check inputs, calculate and set missing variables
         """
+        self.data_FiQuS.cct.geometry = self.model_data.Options_FiQuS.cct.geometry
+        self.data_FiQuS.cct.mesh = self.model_data.Options_FiQuS.cct.mesh
+        self.data_FiQuS.cct.solve = self.model_data.Options_FiQuS.cct.solve
+        self.data_FiQuS.cct.postproc = self.model_data.Options_FiQuS.cct.postproc
+        self.data_FiQuS.cct.steps = self.model_data.Options_FiQuS.cct.steps
 
+    def buildDataMultipole(self):
+        """
+            Load selected conductor data from DataModelMagnet keys, check inputs, calculate and set missing variables
+        """
+        # geom file
         self.data_FiQuS_geo.Roxie_Data = dR.RoxieData(**self.roxie_data.dict())
 
+        # set file
         self.data_FiQuS_set.Model_Data_GS.general_parameters.I_ref =\
             [self.model_data.Options_LEDET.field_map_files.Iref] * len(self.data_FiQuS_geo.Roxie_Data.coil.coils)
         for cond in self.model_data.Conductors:
@@ -61,8 +82,16 @@ class BuilderFiQuS:
             conductor.cable.bare_cable_width = cond.cable.bare_cable_width
             conductor.cable.bare_cable_height_mean = cond.cable.bare_cable_height_mean
 
-        self.data_FiQuS.Model_Data.general_parameters.magnet_name = self.model_data.GeneralParameters.magnet_name
-        self.data_FiQuS.Model_Data.power_supply.I_initial =\
+        # yaml file
+        self.data_FiQuS.multipole.options = self.model_data.Options_FiQuS.multipole.options
+        self.data_FiQuS.multipole.options.plot_all = self.flag_plot_all
+        if self.local_folder:
+            self.data_FiQuS.multipole.options.output_folder = self.local_folder
+
+        self.data_FiQuS.multipole.mesh = self.model_data.Options_FiQuS.multipole.mesh
+
+        self.data_FiQuS.multipole.solve.I_initial = \
             [self.model_data.Power_Supply.I_initial] * len(self.data_FiQuS_geo.Roxie_Data.coil.coils)
-        self.data_FiQuS.Options_FiQuS = self.model_data.Options_FiQuS
-        self.data_FiQuS.Options_FiQuS.options.plot_all = self.flag_plot_all
+        self.data_FiQuS.multipole.solve.pro_template = self.model_data.Options_FiQuS.multipole.solve.pro_template
+
+        self.data_FiQuS.multipole.post_proc = self.model_data.Options_FiQuS.multipole.post_proc
