@@ -16,11 +16,11 @@ class BuilderSIGMA:
         Class to generate SIGMA models
     """
 
-    def __init__(self, input_model_data: DataModelMagnet = None, input_roxie_data: dR.APIdata = None,
+    def __init__(self, input_model_data: DataModelMagnet = None, input_roxie_data: dR.RoxieData = None,
                  settings_dict: dict = None, output_path: str = None, flag_build: bool = True, verbose: bool = True):
         self.verbose: bool = verbose
         self.model_data: DataModelMagnet = input_model_data
-        self.roxie_data: dR.APIdata = input_roxie_data
+        self.roxie_data: dR.RoxieData = input_roxie_data
         self.settings_dict: dict = settings_dict
         if output_path:
             self.output_path: str = output_path
@@ -204,8 +204,12 @@ class BuilderSIGMA:
         self.g.cable.setFracCu(self.cableParameters['strand']['Cu_noCu_in_strand'] /
                                (1 + self.cableParameters['strand']['Cu_noCu_in_strand']))
         self.g.cable.setFracSc(1 / (1 + self.cableParameters['strand']['Cu_noCu_in_strand']))
-        self.g.cable.setC1(self.cableParameters['Jc_fit']['C1_' + self.cableParameters['Jc_fit']['type']])
-        self.g.cable.setC2(self.cableParameters['Jc_fit']['C2_' + self.cableParameters['Jc_fit']['type']])
+        if self.cableParameters['Jc_fit']['type'][:4] == 'CUDI':
+            self.g.cable.setC1(self.cableParameters['Jc_fit']['C1_' + self.cableParameters['Jc_fit']['type']])
+            self.g.cable.setC2(self.cableParameters['Jc_fit']['C2_' + self.cableParameters['Jc_fit']['type']])
+        else:
+            self.g.cable.setC1(0.)
+            self.g.cable.setC2(0.)
 
         self.g.cable.setCriticalSurfaceFit(self.g.Cable.CriticalSurfaceFitEnum.Ic_NbTi_GSI)
         self.g.cable.setInsulationMaterial(self.g.MatDatabase.MAT_KAPTON)
@@ -248,7 +252,8 @@ class BuilderSIGMA:
                         self.coil_areas += [areas[0], areas[1]]
                         windings += (self.g.Winding.ofAreas(self.a.create_area_array(self.g.gateway, areas),
                                                             self.a.create_int_array(self.g.gateway, currents),
-                                                            winding.nco, winding.nco, self.g.cable),)
+                                                            winding.conductors_number, winding.conductors_number,
+                                                            self.g.cable),)
 
                 poles += (self.g.Pole.ofWindings(self.a.create_winding_array(self.g.gateway, windings)),)
 
@@ -441,7 +446,7 @@ class BuilderSIGMA:
 if __name__ == "__main__":
     from steam_sdk.parsers.ParserRoxie import ParserRoxie
 
-    magnet_name = 'MQY_2in1'  #'MBH_2in1'  #'MQXA'  #'MBX'  #'MQXB'   # 'MQXF_V2'  #
+    magnet_name = 'MQXF_V2'  #'MBH_2in1'  #'MQXA'  #'MBX'  #'MQXB'   # 'MQXF_V2'  #
     current_path = Path(__file__).parent
     path = Path.joinpath(current_path.parent.parent, 'tests', 'builders', 'model_library',
                          'magnets', magnet_name, 'input')
