@@ -37,6 +37,8 @@ def lookupModelDataToPyBBQ(key: str, mode='data2PyBBQ'):
     'Options_PyBBQ.physics.QKapLimit': 'Pmax',  # New
     'Options_PyBBQ.physics.TVQRef': 'Tref',  # New
     'Options_PyBBQ.physics.Jc_4K_5T_NbTi': 'Jc_4K_5T_NbTi',
+    'Options_PyBBQ.physics.Power': 'Power',
+    'Options_PyBBQ.physics.Heating_nodes': 'Heating_nodes',
      }
 
     if mode == 'data2PyBBQ':
