@@ -28,7 +28,7 @@ class ParserFiQuS:
         # Load yaml keys into DataModelMagnet dataclass
         with open(file_name + '.yaml', "r") as stream:
             dictionary_yaml = ruamel.yaml.safe_load(stream)
-            self.builder_FiQuS.data_FiQuS = dF.FiQuSData(**dictionary_yaml)
+            self.builder_FiQuS.data_FiQuS = dF.DataFiQuS(**dictionary_yaml)
 
         with open(file_name + '.geom', "r") as stream:
             dictionary_yaml = ruamel.yaml.safe_load(stream)
@@ -58,6 +58,11 @@ class ParserFiQuS:
             print("Output folder {} does not exist. Making it now".format(output_path))
             Path(output_path).mkdir(parents=True)
 
-        dict_to_yaml(self.builder_FiQuS.data_FiQuS.dict(), full_path_file_name + '.yaml', list_exceptions=[])
-        dict_to_yaml(self.builder_FiQuS.data_FiQuS_geo.dict(), full_path_file_name + '.geom', list_exceptions=[])
-        dict_to_yaml(self.builder_FiQuS.data_FiQuS_set.dict(), full_path_file_name + '.set', list_exceptions=[])
+        if self.builder_FiQuS.data_FiQuS.general.magnet_type == 'multipole':
+            dict_to_yaml(self.builder_FiQuS.data_FiQuS.dict(), full_path_file_name + '.yaml', list_exceptions=[])
+            dict_to_yaml(self.builder_FiQuS.data_FiQuS_geo.dict(), full_path_file_name + '.geom', list_exceptions=[])
+            dict_to_yaml(self.builder_FiQuS.data_FiQuS_set.dict(), full_path_file_name + '.set', list_exceptions=[])
+        elif self.builder_FiQuS.data_FiQuS.general.magnet_type == 'CCT':
+            dict_to_yaml(self.builder_FiQuS.data_FiQuS.dict(), full_path_file_name + '.yaml', list_exceptions=[])
+        else:
+            raise Exception('Incompatible magnet type.')
