@@ -13,6 +13,7 @@ from steam_sdk.builders.BuilderLEDET import BuilderLEDET
 from steam_sdk.data.TemplateLEDET import get_template_LEDET_inputs_sheet, get_template_LEDET_options_sheet, get_template_LEDET_plots_sheet, get_template_LEDET_variables_sheet
 from steam_sdk.parsers import ParserMap2d
 from steam_sdk.parsers.ParserExcel import read_row, compare_two_parameters, write2Excel
+from steam_sdk.parsers.dict_to_yaml import dict_to_yaml
 from steam_sdk.utils.NumpyEncoder import NumpyEncoder
 
 
@@ -323,6 +324,7 @@ class ParserLEDET:
             print('New file ' + nameFileLEDET + ' generated.')
         return
 
+
     def writeLedetWorkbookSheet(self, book, sheet, variableGroup, variableLabels, verbose: bool = False):
         """
             **Write one sheet of a LEDET input file**
@@ -440,6 +442,7 @@ class ParserLEDET:
                 cl = get_column_letter(i)
                 sheet1.column_dimensions[cl].width = width[2]
 
+
     def _expandCoolingScalarToArray(self, verbose: bool = False):
         ''' Method adds as many elements as the number of half-turns to selected variables '''
         # TODO: Method can be made more general
@@ -530,6 +533,72 @@ class ParserLEDET:
             print('New file ' + full_path_file_name + ' generated.')
         return
 
+
+    def write2yaml(self, full_path_file_name: str, verbose: bool = True, SkipConsistencyCheck: bool = False):
+        '''
+            *** Function that writes a LEDET input file as a .yaml file ***
+
+            Function to write a LEDET input file containing "Inputs", "Options", "Plots", and "Variables" variables
+
+            :param full_path_file_name: String defining the name of the LEDET input file to be written
+            :type full_path_file_name: string
+            :param verbose: flag that determines whether the output are printed
+            :type verbose: bool
+            :param SkipConsistencyCheck: flag that determines, whether the parameters shall be checked for consistency or not [False = Apply checks, True = Skip checks]
+            :type SkipConsistencyCheck: bool
+
+            :return: None
+        '''
+
+        # Unpack variables
+        builder_ledet = self.builder_ledet
+
+        # Consistency check
+        if not SkipConsistencyCheck:
+            if self._consistencyCheckLEDET():
+                print("Variables are not consistent! Writing aborted - ", full_path_file_name)
+                return
+            else:
+                if verbose: print("Preliminary consistency check was successful! - ", full_path_file_name)
+        else:
+            print("Skipped consistency checks.")
+
+        # Define optional variables, which will be written only if present in the dataclass
+        optional_variables_input_sheet = _getOptionalVariables_input()
+        optional_variables_output_sheet = _getOptionalVariables_output()
+
+        # Write LEDET data into a dictionary
+        ledet_data_dict = {
+            **builder_ledet.Inputs.__dict__,
+            **builder_ledet.Options.__dict__,
+            **builder_ledet.Plots.__dict__,
+            **builder_ledet.Variables.__dict__}  # to add program-specific variables
+
+        # Skip optional variables if they have 0 elements
+        for name, value in ledet_data_dict.copy().items():
+            if (name in optional_variables_input_sheet) or (name in optional_variables_output_sheet):
+                if isinstance(value, list) and len(value) == 0:
+                    if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
+                    del ledet_data_dict[name]
+                elif isinstance(value, np.ndarray) and value.shape[0] == 0:
+                    if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
+                    del ledet_data_dict[name]
+                elif value is None:
+                    if verbose: print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
+                    del ledet_data_dict[name]
+
+        # Write output .yaml file
+        dict_to_yaml(ledet_data_dict, full_path_file_name, list_exceptions=[])
+
+        # Display time stamp
+        currentDT = datetime.datetime.now()
+        if verbose:
+            print(' ')
+            print('Time stamp: ' + str(currentDT))
+            print('New file ' + full_path_file_name + ' generated.')
+        return
+
+
 #######################  Methods for consistency checks of LEDET input files - START  #######################
 # TODO: Update consistency checks of LEDET input files to the latest LEDET features
 
@@ -882,6 +951,7 @@ def _getOptionalVariables_output():
         ]
     return optional_variables_output_sheet
 
+
 def CompareLEDETParameters(fileA, fileB, max_relative_error=1E-5, show_indices=0):
     '''
         Compare all the variables imported from two LEDET Excel input files
