@@ -420,6 +420,7 @@ class ParserPSPICE:
                                 '- controlled-source component\n'
                                 '- pulsed-source component\n'
                                 '- parametrized component\n'
+                                '- transient-source component\n'
                                 'Netlist cannot be generated.')
 
             # Add the relevant row depending on the component type
@@ -446,6 +447,11 @@ class ParserPSPICE:
                     raise Exception('Netlist component in position #{} is of type {} and requires name, nodes, and value.'.format(s+1, type))
                 if verbose: print('Netlist entry {} in position #{} is treated as a controlled-source component.'.format(name, s + 1))
                 rows_netlist.append(add_controlled_source_component(name, nodes, value))
+            elif type == 'transient-source component':
+                if name == None or nodes == None or value == None:
+                    raise Exception('Netlist component in position #{} is of type {} and requires name, nodes, and value.'.format(s+1, type))
+                if verbose: print('Netlist entry {} in position #{} is treated as a transient-source component.'.format(name, s + 1))
+                rows_netlist.append(add_controlled_source_component(name, nodes, value))
             elif type == 'parametrized component':
                 if name == None or nodes == None or value == None:
                     raise Exception('Netlist component in position #{} is of type {} and requires name, nodes, and value.'.format(s+1, type))
@@ -609,11 +615,13 @@ class ParserPSPICE:
             if os.path.isfile(os.path.join(file_to_copy)):
                 print('File {} exists'.format(file_to_copy))
             else:
-                print('File {} does not exist'.format(file_to_copy))
+                print('File {} does not exist. Skipped.'.format(file_to_copy))
+                continue
             if os.path.isdir(self.output_path):
                 print('Dir {} exists'.format(self.output_path))
             else:
-                print('Dir {} does not exist'.format(self.output_path))
+                print('Dir {} does not exist. Skipped.'.format(self.output_path))
+                continue
             shutil.copyfile(Path(file_to_copy), Path(file_to_write))
 
             if verbose:
@@ -676,6 +684,13 @@ def add_controlled_source_component(name: str, nodes: list, value: str):
     formatted_text = name + ' (' + str_nodes + ') ' + str_stimulus
     return formatted_text
 
+def add_transient_source_component(name: str, nodes: list, value: str):
+    ''' Format controlled-source component netlist row '''
+    str_nodes = " ".join(nodes)  # string with space-separated nodes
+    str_stimulus = 'AC ' + '{' + value + '}'
+    formatted_text = name + ' (' + str_nodes + ') ' + str_stimulus
+    return formatted_text
+
 def add_parametrized_component(name: str, nodes: list, value: str, parameters: dict):
     ''' Format parametrized component netlist row '''
     str_nodes = " ".join(nodes)  # string with space-separated nodes
