@@ -5,7 +5,7 @@ import matplotlib.pyplot as plt
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 
 from steam_sdk.data import DataModelMagnet
-from steam_sdk.data.DataRoxieParser import APIdata
+from steam_sdk.data.DataRoxieParser import RoxieData
 from steam_sdk.parsers.ParserRoxie import RoxieList
 from steam_sdk.utils.misc import displayWaitAndClose, find_indices
 from steam_sdk.plotters import PlotterRoxie
@@ -13,7 +13,7 @@ from steam_sdk.parsers.ParserMap2d import getParametersFromMap2d
 
 
 class PlotterModel:
-    def __init__(self, roxie_data: APIdata = None):
+    def __init__(self, roxie_data: RoxieData = None):
         if roxie_data:
             RL = RoxieList(roxie_data)
             self.x_insulated = RL.x_insulated
