@@ -150,8 +150,7 @@ def plotEdges(xPos, yPos, xBarePos, yBarePos, iPos, selectedFont):
     plt.grid()
 
 
-
-def plot_all(roxie_data: pd.APIdata):
+def plot_all(roxie_data: pd.RoxieData):
     """
         Plot all default plots
     """
